@@ -1,9 +1,9 @@
 # pylint: disable=unused-argument,invalid-name,line-too-long
 
-from typing import List
 
 from parse import parse
 from sqlalchemy import text as sql_text
+from sqlalchemy.sql.elements import TextClause
 
 from alembic_utils.exceptions import SQLParseFailure
 from alembic_utils.replaceable_entity import ReplaceableEntity
@@ -37,18 +37,18 @@ class PGView(ReplaceableEntity):
 
         raise SQLParseFailure(f'Failed to parse SQL into PGView """{sql}"""')
 
-    def to_sql_statement_create(self) -> str:
+    def to_sql_statement_create(self) -> TextClause:
         """Generates a SQL "create view" statement"""
         return sql_text(
             f'CREATE VIEW {self.literal_schema}."{self.signature}" AS {self.definition};'
         )
 
-    def to_sql_statement_drop(self, cascade=False) -> str:
+    def to_sql_statement_drop(self, cascade=False) -> TextClause:
         """Generates a SQL "drop view" statement"""
         cascade = "cascade" if cascade else ""
         return sql_text(f'DROP VIEW {self.literal_schema}."{self.signature}" {cascade}')
 
-    def to_sql_statement_create_or_replace(self) -> str:
+    def to_sql_statement_create_or_replace(self) -> TextClause:
         """Generates a SQL "create or replace view" statement
 
         If the initial "CREATE OR REPLACE" statement does not succeed,
@@ -70,7 +70,7 @@ class PGView(ReplaceableEntity):
         )
 
     @classmethod
-    def from_database(cls, sess, schema) -> List["PGView"]:
+    def from_database(cls, sess, schema):
         """Get a list of all functions defined in the db"""
         sql = sql_text(
             f"""
